@@ -153,7 +153,7 @@ def get_model(model_name, trial, custom_params_fn=None):
     params = params_fn(trial)
     custom_params = custom_params_fn(trial) if custom_params_fn is not None else {}
     custom_params.update(params)
-    return model(custom_params)
+    return model(**custom_params)
 
 class EarlyStoppingError(Exception):
     pass
@@ -212,60 +212,4 @@ def optimize(model_name, scorer, y_column, trials=30, sampler=TPESampler(seed=66
         print("Stopped with early stopping")
     live.clear()
 
-    return study.best_params
-
-
-
-def create_super_learner(trial, models, head_models):
-    selected_model_names = []
-    n_models = trial.suggest_int('n_models', 1, min(6, len(models)))
-    names = list(models.keys())
-    for i in range(n_models):
-        model_item = trial.suggest_categorical('model_{}'.format(i), names)
-        if model_item not in selected_model_names:
-            selected_model_names.append(model_item)
-
-    folds = trial.suggest_int('folds', 2, 6)
-    model = SuperLearner(folds=folds)
-
-    selected_models = [models[item] for item in selected_model_names]
-    model.add(selected_models)
-
-    head_names = list(head_models.keys())
-    head = trial.suggest_categorical('head', head_names)
-    model.add_meta(head_models[head])
-    print(f"Try: {selected_model_names}, {head}")
-    return model
-
-
-def optimize_super_learner(models, head_models, scorer, y_column, trials=30, sampler=TPESampler(seed=666),
-                           direction='maximize', patience=100, threshold=1e-3, feature_selection_support=None,
-                           feature_selection_cols=None, ds=None, path=None):
-
-    X_ds, y_ds = read_dataset(ds, path, y_column, feature_selection_support, feature_selection_cols)
-    X_train, X_val, y_train, y_val = train_test_split(X_ds, y_ds)
-    scorer_fn = get_score_fn(scorer)
-
-    live = LivePyPlot(direction)
-    stopping = EarlyStopping(direction, patience, threshold)
-
-    def objective(trial):
-        model = create_super_learner(trial, models, head_models)
-        model.fit(X_train, y_train)
-        preds = model.predict(X_val)
-        error = scorer_fn(y_val, preds)
-        live(error)
-        stopping(error)
-        return error
-
-    study = optuna.create_study(direction=direction, sampler=sampler)
-
-    try:
-        study.optimize(objective, n_trials=trials, n_jobs=-1)
-    except KeyboardInterrupt:
-        print("Stopped with keyboard")
-    except EarlyStoppingError:
-        print("Stopped with early stopping")
-    live.clear()
-
-    return study.best_params
+    return live.best, study.best_params
